-----------------------------------------------------------------------------

local L = AceLibrary("AceLocale-2.2"):new("Aloft")
local SML = AceLibrary("SharedMedia-1.0")
local SML_font = SML:List("font")
local SML_statusbar = SML:List("statusbar")

-----------------------------------------------------------------------------

Aloft.OnMenuRequest = 
{
	handler = Aloft,
	type = 'group',
	args = 
	{
		show =
		{
			type = 'toggle',
			name = L["Show Nameplates"],
			desc = L["Show nameplates for neutral or hostile units"],
			get = function() return NAMEPLATES_ON end,
			set = function(v) if v then ShowNameplates() else HideNameplates() end NAMEPLATES_ON = v end,
			order = 1
		},
		showFriendly =
		{
			type = 'toggle',
			name = L["Show Friendly Nameplates"],
			desc = L["Show nameplates for friendly units"],
			get = function() return FRIENDNAMEPLATES_ON end,
			set = function(v) if v then ShowFriendNameplates() else HideFriendNameplates() end FRIENDNAMEPLATES_ON = v end,
			order = 2
		},
		reportStatusChanges =
		{
			type = 'toggle',
			name = L["Report Status Changes"],
			desc = L["Prints the status of nameplates whenever they change"],
			get = function() return Aloft.db.profile.reportStatusChanges end,
			set = function(v) Aloft.db.profile.reportStatusChanges = v end,
			order = 3
		},
		spacer = 
		{
			type = 'header',
			order = 4,
		},
	
		healthBar =
		{
			type = 'group',
			name = L["Health Bar"],
			desc = L["Health Bar options"],
			args =
			{
				texture =
				{
					type = "text", 
					name = L["Texture"], 
					desc = L["Sets the health bar texture"],
					get = function() return Aloft.db.profile.healthBar.texture end,
					set = function(v) Aloft.db.profile.healthBar.texture = v Aloft:UpdateHealthBars() end,
					validate = SML_statusbar,
				},
				width =
				{
					type = 'range',
					name = L["Width"],
					desc = L["Sets the width of the health bar"],
					min = 50,
					max = 250,
					step = 1,
					get = function() return Aloft.db.profile.healthBar.width end,
					set = function(v) Aloft.db.profile.healthBar.width = v Aloft:UpdateHealthBarSize() end,
				},
				height =
				{
					type = 'range',
					name = L["Height"],
					desc = L["Sets the height of the health bar"],
					min = 4,
					max = 40,
					step = 1,
					get = function() return Aloft.db.profile.healthBar.height end,
					set = function(v) Aloft.db.profile.healthBar.height = v Aloft:UpdateHealthBarSize() end,
				},
				alpha =
				{
					type = 'range',
					name = L["Alpha"],
					desc = L["Sets the health bar alpha"],
					min = 0,
					max = 1.0,
					step = 0.05,
					get = function() return Aloft.db.profile.healthBar.alpha end,
					set = function(v) Aloft.db.profile.healthBar.alpha = v Aloft:UpdateHealthBars() end
				},
				colorByClass =
				{
					type = 'toggle',
					name = L["Color by Class"],
					desc = L["Sets the health bar color according to class. Requires Prat.PlayerNames enabled to show out of group colors"],
					get = function() return Aloft.db.profile.healthBar.colorByClass end,
					set = function(v) Aloft.db.profile.healthBar.colorByClass = v Aloft:UpdateHealthBars() end
				},
				groupOnly =
				{
					type = 'toggle',
					name = L["Group Only"],
					desc = L["Only colors group member's health bars by class"],
					disabled = function() return not Aloft.db.profile.healthBar.colorByClass end,
					get = function() return Aloft.db.profile.healthBar.groupOnly end,
					set = function(v) Aloft.db.profile.healthBar.groupOnly = v Aloft:UpdateHealthBars() end
				},
				colors =
				{
					type = 'group',
					name = L["Colors"],
					desc = L["Customize colors"],
					args =
					{
						friendlyPlayer =
						{
							type = 'color',
							name = L["Friendly Players"],
							desc = L["Sets the health bar color for friendly players"],
							get = function() return unpack(Aloft.db.profile.healthBar.colors.friendlyPlayer) end,
							set = function(r, g, b) Aloft.db.profile.healthBar.colors.friendlyPlayer = { r, g, b } Aloft:UpdateHealthBars() end
						},
						friendlyNPC =
						{
							type = 'color',
							name = L["Friendly NPCs"],
							desc = L["Sets the health bar color for friendly NPCs"],
							get = function() return unpack(Aloft.db.profile.healthBar.colors.friendlyNPC) end,
							set = function(r, g, b) Aloft.db.profile.healthBar.colors.friendlyNPC = { r, g, b } Aloft:UpdateHealthBars() end
						},
						friendlyBoss =
						{
							type = 'color',
							name = L["Friendly Boss"],
							desc = L["Sets the health bar color for friendly NPC Bosses"],
							get = function() return unpack(Aloft.db.profile.healthBar.colors.friendlyBoss) end,
							set = function(r, g, b) Aloft.db.profile.healthBar.colors.friendlyBoss = { r, g, b } Aloft:UpdateHealthBars() end
						},
						hostile =
						{
							type = 'color',
							name = L["Hostile Units"],
							desc = L["Sets the health bar color for hostile units"],
							get = function() return unpack(Aloft.db.profile.healthBar.colors.hostile) end,
							set = function(r, g, b) Aloft.db.profile.healthBar.colors.hostile = { r, g, b } Aloft:UpdateHealthBars() end
						},
						hostileBoss =
						{
							type = 'color',
							name = L["Hostile Boss"],
							desc = L["Sets the health bar color for hostile boss units"],
							get = function() return unpack(Aloft.db.profile.healthBar.colors.hostileBoss) end,
							set = function(r, g, b) Aloft.db.profile.healthBar.colors.hostileBoss = { r, g, b } Aloft:UpdateHealthBars() end
						},
						neutral =
						{
							type = 'color',
							name = L["Neutral Units"],
							desc = L["Sets the health bar color for neutral units"],
							get = function() return unpack(Aloft.db.profile.healthBar.colors.neutral) end,
							set = function(r, g, b) Aloft.db.profile.healthBar.colors.neutral = { r, g, b } Aloft:UpdateHealthBars() end
						},
						groupPet =
						{
							type = 'color',
							name = L["Group Pets"],
							desc = L["Sets the health bar color for group pets"],
							get = function() return unpack(Aloft.db.profile.healthBar.colors.groupPet) end,
							set = function(r, g, b) Aloft.db.profile.healthBar.colors.groupPet = { r, g, b } Aloft:UpdateHealthBars() end
						},
					}
				}
			},
		},

		castBarOverlay =
		{
			type = 'group',
			name = L["Cast Bar Overlay"],
			desc = L["Cast bar overlay options"],
			args =
			{
				enable =
				{
					type = 'toggle',
					name = L["Enable"],
					desc = L["Show an overlay on the full cast bar"],
					get = function() return Aloft.db.profile.castBarOverlay.enable end,
					set = function(v) Aloft.db.profile.castBarOverlay.enable = v Aloft:UpdateCastBarOverlays() end
				},
				color =
				{
					type = 'color',
					name = L["Color"],
					desc = L["Sets the cast bar overlay color"],
					get = function() return unpack(Aloft.db.profile.castBarOverlay.color) end,
					set = function(r, g, b, a) Aloft.db.profile.castBarOverlay.color = { r, g, b, a } Aloft:UpdateCastBarOverlays() end,
					hasAlpha = true
				},
				texture =
				{
					type = "text", 
					name = L["Texture"], 
					desc = L["Sets the cast bar overlay texture"],
					get = function() return Aloft.db.profile.castBarOverlay.texture end,
					set = function(v) Aloft.db.profile.castBarOverlay.texture = v Aloft:UpdateCastBarOverlays() end,
					validate = SML_statusbar,
				},
				horizontalPadding =
				{
					type = 'range',
					name = L["Horizontal Padding"],
					desc = L["Horizontal padding of the overlay texture compared to the the cast bar"],
					min = 0,
					max = 8,
					step = 0.1,
					disabled = function() return Aloft.db.profile.castBarOverlay.emulateBackground end,
					get = function() return Aloft.db.profile.castBarOverlay.horizontalPadding end,
					set = function(v) Aloft.db.profile.castBarOverlay.horizontalPadding = v Aloft:UpdateCastBarOverlays() end
				},
				verticalPadding =
				{
					type = 'range',
					name = L["Vertical Padding"],
					desc = L["Vertical padding of the overlay texture compared to the the cast bar"],
					min = 0,
					max = 8,
					step = 0.1,
					disabled = function() return Aloft.db.profile.castBarOverlay.emulateBackground end,
					get = function() return Aloft.db.profile.castBarOverlay.verticalPadding end,
					set = function(v) Aloft.db.profile.castBarOverlay.verticalPadding = v Aloft:UpdateCastBarOverlays() end
				},
				emulateBackground = 
				{
					type = 'toggle',
					name = L["Emulate Background"],
					desc = L["Dynamically adjust the position of the cast bar overlay texture to make it appear as a background to the cast bar"],
					get = function() return Aloft.db.profile.castBarOverlay.emulateBackground end,
					set = function(v) Aloft.db.profile.castBarOverlay.emulateBackground = v Aloft:UpdateCastBarOverlays() end
				},
			},
		},
	
		castBar =
		{
			type = 'group',
			name = L["Cast Bar"],
			desc = L["Cast bar options"],
			args =
			{
				enable =
				{
					type = 'toggle',
					name = L["Enable"],
					desc = L["Show cast bars"],
					get = function() return GetCVar("ShowVKeyCastbar") == "1" end,
					set = function(v) SetCVar("ShowVKeyCastbar", v and "1" or "0") end
				},
				position =
				{
					type = 'group',
					name = L["Position"],
					desc = L["Adjust cast bar position"],
					args =
					{
						left =
						{
							type = 'range',
							name = L["Left Offset"],
							desc = L["Sets the offset of the left of the cast bar"],
							min = -32,
							max = 32,
							step = 1,
							get = function() return Aloft.db.profile.castBar.offsets.left end,
							set = function(v) Aloft.db.profile.castBar.offsets.left = v Aloft:UpdateCastBars() end
						},
						right =
						{
							type = 'range',
							name = L["Right Offset"],
							desc = L["Sets the offset of the right of the cast bar"],
							min = -32,
							max = 32,
							step = 1,
							get = function() return Aloft.db.profile.castBar.offsets.right end,
							set = function(v) Aloft.db.profile.castBar.offsets.right = v Aloft:UpdateCastBars() end
						},
						vertical =
						{
							type = 'range',
							name = L["Vertical Offset"],
							desc = L["Sets the vertical offset of the cast bar"],
							min = -32,
							max = 32,
							step = 1,
							get = function() return Aloft.db.profile.castBar.offsets.vertical end,
							set = function(v) Aloft.db.profile.castBar.offsets.vertical = v Aloft:UpdateCastBars() end
						},
					},
				},
				height =
				{
					type = 'range',
					name = L["Height"],
					desc = L["Sets the height of the cast bar"],
					min = 5,
					max = 32,
					step = 1,
					get = function() return Aloft.db.profile.castBar.height end,
					set = function(v) Aloft.db.profile.castBar.height = v Aloft:UpdateCastBars() end
				},
				texture =
				{
					type = "text", 
					name = L["Texture"], 
					desc = L["Sets the cast bar texture"],
					get = function() return Aloft.db.profile.castBar.texture end,
					set = function(v) Aloft.db.profile.castBar.texture = v Aloft:UpdateCastBars() end,
					validate = SML_statusbar,
				},
			},
		},		
	},
}

Aloft:RegisterChatCommand({"/aloft"}, Aloft.OnMenuRequest)

-----------------------------------------------------------------------------
